@@ -38,23 +38,23 @@ scene = soya.World()
 
 
 # Creates the randomly moving sphere's class. We call it head, because we'll use
-# a head-like shape.
-# This class inherits from soya.Volume, so it can have a shape (the head).
+# a head-like model.
+# This class inherits from soya.Body, so it can have a model (the head).
 		
-class Head(soya.Volume):
+class Head(soya.Body):
 	
 	# Redefine the constructor.
 	
 	def __init__(self, parent):
 		
-		# Calls the soya.Volume constructor (remember, calling the super implementation is
-		# always a good idea), and use the shape called 'caterpillar_head'.
+		# Calls the soya.Body constructor (remember, calling the super implementation is
+		# always a good idea), and use the model called 'caterpillar_head'.
 		
-		soya.Volume.__init__(self, parent, soya.Shape.get("caterpillar_head"))
+		soya.Body.__init__(self, parent, soya.Model.get("caterpillar_head"))
 		
 		# Adds a speed attribute to our new object.
 		# The speed is a Vector object. A Vector is a mathematical object, used for
-		# computation ; contrary to other object (Light, Camera, Volume, World,...) it does not
+		# computation ; contrary to other object (Light, Camera, Body, World,...) it does not
 		# modify the rendering in any way.
 		
 		# A vector is defined by a coordinate system and 3 coordinates (X, Y, Z) ; here the
@@ -64,8 +64,12 @@ class Head(soya.Volume):
 		# at, and has a length of 0.2.
 		
 		self.speed = soya.Vector(self, 0.0, 0.0, -0.2)
-
-	# Like advance_time, begin_round is called by the idler.
+		
+		# The current rotation speed (around Y axis)
+		
+		self.rotation_speed = 0.0
+		
+	# Like advance_time, begin_round is called by the main_loop.
 	# But contrary to advance_time, begin_round is called regularly, at the beginning of each
 	# round ; thus it receive no 'proportion' argument.
 	# Decision process should occurs in begin_round.
@@ -74,26 +78,29 @@ class Head(soya.Volume):
 		
 		# Calls the super implementation.
 		
-		soya.Volume.begin_round(self)
+		soya.Body.begin_round(self)
 		
-		# Changes the direction of the head, by rotating it around the Y axis, of a random
-		# angle between -25.0 and 25.0 degrees.
+		# Computes the new rotation speed: a random angle between -25.0 and 25.0 degrees.
 		
-		# Notice that after the rotation, the speed vector is still parallel to the direction
-		# the head is looking at, since the vector is defined 'inside' the head. 
+		self.rotation_speed = random.uniform(-25.0, 25.0)
 		
-		self.rotate_y((random.random() - 0.5) * 50.0)
+		# The speed vector doesn't need to be recomputed, since it is expressed in the Head
+		# CoordSyst.
 		
 	# In advance_time, we make the head advance.
 	
 	def advance_time(self, proportion):
-		soya.Volume.advance_time(self, proportion)
+		soya.Body.advance_time(self, proportion)
+		
+		# Performs the rotation, taking into account the proportion argument.
+		
+		self.rotate_y(proportion * self.rotation_speed)
 		
 		# Moves the head according to the speed vector.
 		# add_mul_vector is identical to: self.add_vector(proportion * self.speed), but faster.
 		
-		# Notice that the head is defined is the head.parent coordinate system (e.g. the scene)
-		# though the speed vector is defined in the head coordinate system. 
+		# The speed vector and the Head are not in the same coordinate system, but Soya automatically
+		# performs the needed conversion.
 		
 		self.add_mul_vector(proportion, self.speed)
 
@@ -120,4 +127,10 @@ camera.set_xyz(0.0, 15.0, 15.0)
 
 camera.look_at(head)
 
-soya.Idler(scene).idle()
+#import time; main_loop = soya.MainLoop(scene)
+#for i in range(3):
+#	for j in range(5):
+#		time.sleep(0.1); main_loop.update()
+#	soya.render(); soya.screenshot().resize((320, 240)).save(os.path.join(os.path.dirname(sys.argv[0]), "results", os.path.basename(sys.argv[0])[:-3] + "_%s.jpeg" % i))
+
+soya.MainLoop(scene).main_loop()
