@@ -43,18 +43,18 @@ scene = soya.World()
 # It is identical to the Head class of lesson basic-3.py, except the class name.
 # So... no comment!
 
-class CaterpillarHead(soya.Volume):
+class CaterpillarHead(soya.Body):
 	def __init__(self, parent):
-		soya.Volume.__init__(self, parent, soya.Shape.get("caterpillar_head"))
+		soya.Body.__init__(self, parent, soya.Model.get("caterpillar_head"))
 		self.speed = soya.Vector(self, 0.0, 0.0, -0.2)
 		
 	def begin_round(self):
-		soya.Volume.begin_round(self)
+		soya.Body.begin_round(self)
 		
 		self.rotate_y((random.random() - 0.5) * 50.0)
 		
 	def advance_time(self, proportion):
-		soya.Volume.advance_time(self, proportion)
+		soya.Body.advance_time(self, proportion)
 		
 		self.add_mul_vector(proportion, self.speed)
 
@@ -62,19 +62,19 @@ class CaterpillarHead(soya.Volume):
 # A CaterpillarPiece is a piece of the body of the caterpillar.
 # It follows another object -- the previous piece, or the head for the first one.
 
-class CaterpillarPiece(soya.Volume):
+class CaterpillarPiece(soya.Body):
 	
 	# The constructor takes two arguments: the parent and the previous piece of body that
 	# we must follow.
 	# Similarly to the head, we define a speed vector.
 	
 	def __init__(self, parent, previous):
-		soya.Volume.__init__(self, parent, soya.Shape.get("caterpillar"))
+		soya.Body.__init__(self, parent, soya.Model.get("caterpillar"))
 		self.previous = previous
 		self.speed = soya.Vector(self, 0.0, 0.0, -0.2)
 		
 	def begin_round(self):
-		soya.Volume.begin_round(self)
+		soya.Body.begin_round(self)
 		
 		# We rotates the caterpillar piece so as it looks toward the previous piece.
 		
@@ -92,7 +92,7 @@ class CaterpillarPiece(soya.Volume):
 	# advance_time is identical to the CaterpillarHead ones.
 	
 	def advance_time(self, proportion):
-		soya.Volume.advance_time(self, proportion)
+		soya.Body.advance_time(self, proportion)
 		
 		self.add_mul_vector(proportion, self.speed)
 		
@@ -121,7 +121,7 @@ camera.set_xyz(0.0, 15.0, 15.0)
 camera.look_at(caterpillar_head)
 soya.set_root_widget(camera)
 
-soya.Idler(scene).idle()
+soya.MainLoop(scene).main_loop()
 
 
 # For information, the caterpillar textures were done in the Gimp, and the model were
