@@ -41,14 +41,14 @@ soya.path.append(os.path.join(os.path.dirname(sys.argv[0]), "data"))
 scene = soya.World()
 
 
-class CaterpillarHead(soya.Volume):
+class CaterpillarHead(soya.Body):
 	def __init__(self, parent):
-		soya.Volume.__init__(self, parent, soya.Shape.get("caterpillar_head"))
+		soya.Body.__init__(self, parent, soya.Model.get("caterpillar_head"))
 		self.speed                  = soya.Vector(self, 0.0, 0.0, 0.0)
 		self.rotation_y_speed = 0.0
 		
 	def begin_round(self):
-		soya.Volume.begin_round(self)
+		soya.Body.begin_round(self)
 		
 		for event in soya.process_event():
 			if event[0] == soya.sdlconst.KEYDOWN:
@@ -57,8 +57,8 @@ class CaterpillarHead(soya.Volume):
 				
 				elif event[1] == soya.sdlconst.K_LEFT:   self.rotation_y_speed =  10.0
 				elif event[1] == soya.sdlconst.K_RIGHT:  self.rotation_y_speed = -10.0
-				elif event[1] == soya.sdlconst.K_q:      soya.IDLER.stop()
-				elif event[1] == soya.sdlconst.K_ESCAPE: soya.IDLER.stop()
+				elif event[1] == soya.sdlconst.K_q:      soya.MAIN_LOOP.stop()
+				elif event[1] == soya.sdlconst.K_ESCAPE: soya.MAIN_LOOP.stop()
 			
 			if event[0] == soya.sdlconst.KEYUP:
 				if   event[1] == soya.sdlconst.K_UP:     self.speed.z = 0.0
@@ -69,24 +69,24 @@ class CaterpillarHead(soya.Volume):
 		self.rotate_y(self.rotation_y_speed)
 		
 	def advance_time(self, proportion):
-		soya.Volume.advance_time(self, proportion)
+		soya.Body.advance_time(self, proportion)
 		self.add_mul_vector(proportion, self.speed)
 
 
-class CaterpillarPiece(soya.Volume):
+class CaterpillarPiece(soya.Body):
 	def __init__(self, parent, previous):
-		soya.Volume.__init__(self, parent, soya.Shape.get("caterpillar"))
+		soya.Body.__init__(self, parent, soya.Model.get("caterpillar"))
 		self.previous = previous
 		self.speed = soya.Vector(self, 0.0, 0.0, -0.2)
 		
 	def begin_round(self):
-		soya.Volume.begin_round(self)
+		soya.Body.begin_round(self)
 		self.look_at(self.previous)
 		if self.distance_to(self.previous) < 1.5: self.speed.z =  0.0
 		else:                                     self.speed.z = -0.2
 		
 	def advance_time(self, proportion):
-		soya.Volume.advance_time(self, proportion)
+		soya.Body.advance_time(self, proportion)
 		self.add_mul_vector(proportion, self.speed)
 		
 
@@ -112,4 +112,4 @@ camera.set_xyz(0.0, 15.0, 15.0)
 camera.look_at(caterpillar_head)
 soya.set_root_widget(camera)
 
-soya.Idler(scene).idle()
+soya.MainLoop(scene).main_loop()
