@@ -20,10 +20,10 @@
 
 # modeling-shadow-1: Modeling : shadows !
 
-# Shadows must be enabled both on the light that casts the shadow, and on the shape
+# Shadows must be enabled both on the light that casts the shadow, and on the model
 # that projects it.
 
-# The shadow algorithm assume that non-double sided faces are part of closed volumes, so
+# The shadow algorithm assume that non-double sided faces are part of closed bodys, so
 # you should take this into account when designing your models.
 # Nothing is assumed for double sided faces, though, so in doubt, use double sided faces.
 
@@ -46,43 +46,43 @@ scene = soya.World()
 
 sword = soya.World.get("sword")
 
-# Creates a simple shape shapifier object. A shapifier is an object that says how a world
-# is compiled into a shape. When no shapifier is specified, Soya uses the default shapifier
-# (an instance of SimpleShapifier, that does not include shadows).
+# Creates a simple model model_builder object. A model_builder is an object that says how a world
+# is compiled into a model. When no model_builder is specified, Soya uses the default model_builder
+# (an instance of SimpleModelBuilder, that does not include shadows).
 
-shapifier = soya.SimpleShapifier()
+model_builder = soya.SimpleModelBuilder()
 
-# Sets the 'shadow' shapifier property to true.
+# Sets the 'shadow' model_builder property to true.
 
-shapifier.shadow = 1
+model_builder.shadow = 1
 
-# Assigns the shapifier to the sword.
+# Assigns the model_builder to the sword.
 
-sword.shapifier = shapifier
+sword.model_builder = model_builder
 
-# Compiles the sword model to a shadowed shape. Notice that is you save the sword now,
-# the shapifier would be saved with it too, and thus you can use 'soya.Shape.get("sword")'.
+# Compiles the sword model to a shadowed model. Notice that is you save the sword now,
+# the model_builder would be saved with it too, and thus you can use 'soya.Model.get("sword")'.
 
-sword_shape = sword.shapify()
+sword_model = sword.to_model()
 
-# Create a rotating volume class, and a rotating volume.
+# Create a rotating body class, and a rotating body.
 
-class RotatingVolume(soya.Volume):
-	def __init__(self, parent = None, shape = None):
-		soya.Volume.__init__(self, parent, shape)
+class RotatingBody(soya.Body):
+	def __init__(self, parent = None, model = None):
+		soya.Body.__init__(self, parent, model)
 		
 	def advance_time(self, proportion):
-		soya.Volume.advance_time(self, proportion)
+		soya.Body.advance_time(self, proportion)
 		
 		self.rotate_y(proportion * 2.0)
 			
 			
-volume = RotatingVolume(scene, sword_shape)
-volume.set_xyz(1.0, -1.0, 0.0)
-volume.rotate_x(90.0)
+body = RotatingBody(scene, sword_model)
+body.set_xyz(1.0, -1.0, 0.0)
+body.rotate_x(90.0)
 
 # Creates a wall, to receive the shadow.
-# Notice that the wall can be any object (including e.g. a landscape,...) : receiving
+# Notice that the wall can be any object (including e.g. a terrain,...) : receiving
 # shadows doesn't require any particular property.
 
 wall_model = soya.World()
@@ -93,7 +93,7 @@ wall_face = soya.Face(wall_model, [
 	soya.Vertex(wall_model, 0.0,  5.0, -5.0),
 	])
 wall_face.double_sided = 1
-wall = soya.Volume(scene, wall_model.shapify())
+wall = soya.Body(scene, wall_model.to_model())
 wall.set_xyz(-1.0, 0.0, 0.0)
 
 # Creates a light.
@@ -115,4 +115,4 @@ camera = soya.Camera(scene)
 camera.set_xyz(0.0, 0.0, 3.5)
 soya.set_root_widget(camera)
 
-soya.Idler(scene).idle()
+soya.MainLoop(scene).main_loop()
