@@ -50,11 +50,11 @@ scene = soya.World()
 
 # here we use the built in FireWork system. auto_generate_particle is 
 # on by default so this will continue forever
-fountain = particle.FlagFirework(scene, nb_particles=4, nb_sub_particles=10)
+#fountain = particle.FlagFirework(scene, nb_particles=4, nb_sub_particles=10)
 
 # this is slightly more dull
 # you will notice that this doesnt automatically set auto_generate_particle
-#smoke=particle.Smoke(scene)
+smoke=particle.Smoke(scene)
 
 # here we use the same smoke particle system but set auto_generate_particle
 # so that it continues
@@ -91,16 +91,16 @@ camera = soya.Camera(scene)
 camera.z = 10.0
 soya.set_root_widget(camera)
 
-# make an idler that stops on any keystroke
-class Idler(soya.Idler):
+# make an main_loop that stops on any keystroke
+class MainLoop(soya.MainLoop):
 	def begin_round(self):
-		soya.Idler.begin_round(self)
+		soya.MainLoop.begin_round(self)
 
 		# wait for any keystoke to quit
 		for e in soya.process_event():
 			if e[0]==sdlconst.KEYDOWN and e[1]!=0:
 				self.stop()        
 
-Idler(scene).idle()
+MainLoop(scene).main_loop()
 
 
