@@ -15,8 +15,8 @@ pudding.init()
 
 scene = soya.World()
 
-sword_model = soya.Shape.get("sword")
-sword = soya.Volume(scene, sword_model)
+sword_model = soya.Model.get("sword")
+sword = soya.Body(scene, sword_model)
 sword.x = 1
 sword.rotate_y(90.)
 
@@ -29,31 +29,31 @@ light.set_xyz( .5, 0., 2.)
 camera = soya.Camera(scene)
 camera.z = 3.
 
-class PuddingVolume(pudding.core.Control):
+class PuddingBody(pudding.core.Control):
 	def __set_left__(self, left):
 		pudding.core.Control.__set_left__(self, left)
-		self.move_shape()
+		self.move_model()
 		
 	def __set_top__(self, top):
 		pudding.core.Control.__set_top(self, top)
-		self.move_shape()
+		self.move_model()
 	
 	def __init__(self, *args, **kwargs):
 		pudding.core.Control.__init__(self, *args, **kwargs)
-		self.shape = soya.Volume(scene, sword_model)
-		self.shape.rotate_y(90) 
-		self.shape.scale(.5, .5, .5)
-		self.move_shape()
+		self.model = soya.Body(scene, sword_model)
+		self.model.rotate_y(90) 
+		self.model.scale(.5, .5, .5)
+		self.move_model()
 
 	def on_resize(self):
-		self.move_shape()
+		self.move_model()
 
-	def move_shape(self):
-		self.shape.move(camera.coord2d_to_3d(self.left, self.top))
+	def move_model(self):
+		self.model.move(camera.coord2d_to_3d(self.left, self.top))
 
 w = pudding.core.RootWidget(width = 1024,height = 768)
 
-d = PuddingVolume(w, 200, 100, 100, 100)
+d = PuddingBody(w, 200, 100, 100, 100)
 
 button_bar = pudding.container.HorizontalContainer( w, left = 10, width= 164, height=64)
 button_bar.set_pos_bottom_right(bottom = 10)
@@ -69,5 +69,5 @@ w.add_child(camera)
 
 soya.set_root_widget(w)
 
-pudding.idler.Idler(scene).idle()
+pudding.main_loop.MainLoop(scene).main_loop()
 
