@@ -22,8 +22,8 @@ print "Choosen font :", myfont
 
 scene = soya.World()
 
-sword_model = soya.Shape.get("sword")
-sword = soya.Volume(scene, sword_model)
+sword_model = soya.Model.get("sword")
+sword = soya.Body(scene, sword_model)
 sword.x = 1
 sword.rotate_y(90.0)
 
@@ -67,5 +67,5 @@ root.add_child(camera)
 # we need to do this to force the layout to refresh
 root.on_resize()
 
-pudding.idler.Idler(scene).idle()
+pudding.main_loop.MainLoop(scene).main_loop()
 
