@@ -20,8 +20,8 @@ pudding.init()
 
 scene = soya.World()
 
-sword_model = soya.Shape.get("sword")
-sword = soya.Volume(scene, sword_model)
+sword_model = soya.Model.get("sword")
+sword = soya.Body(scene, sword_model)
 sword.y = -1
 sword.x = -1.5
 sword.rotate_x(90.)
@@ -111,5 +111,5 @@ w.add_child(camera)
 
 soya.set_root_widget(w)
 
-pudding.idler.Idler(scene).idle()
+pudding.main_loop.MainLoop(scene).main_loop()
 
