@@ -17,8 +17,8 @@ pudding.init()
 
 scene = soya.World()
 
-sword_model = soya.Shape.get("sword")
-sword = soya.Volume(scene, sword_model)
+sword_model = soya.Model.get("sword")
+sword = soya.Body(scene, sword_model)
 sword.x = 1
 sword.rotate_y(90.)
 
@@ -47,5 +47,5 @@ meter.border_color = (1, 1, 1, 1)
 
 soya.root_widget.add_child(camera)
 
-pudding.idler.Idler(scene).idle()
+pudding.main_loop.MainLoop(scene).main_loop()
 
