@@ -18,11 +18,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
-# basic-5: Event management : a keyboard-controlled caterpillar
+# traveling-camera-1: Traveling camera : a keyboard-controlled caterpillar, followed by the camera!
 
 # In this lesson, our caterpillar will obey you !
-# You'll learn how to use SDL events with Soya.
-# Use the cursor arrows to control the caterpillar.
 
 
 # Import the Soya module.
@@ -38,18 +36,25 @@ soya.path.append(os.path.join(os.path.dirname(sys.argv[0]), "data"))
 scene = soya.World()
 
 
-# The CaterpillarHead class is very similar to the CaterpillarHead class of the previous
-# lesson.
+# The CaterpillarHead class is very similar to the CaterpillarHead class of the basic-*
+# lessons.
 
-class CaterpillarHead(soya.Volume):
+class CaterpillarHead(soya.Body):
 	def __init__(self, parent):
-		soya.Volume.__init__(self, parent, soya.Shape.get("caterpillar_head"))
+		soya.Body.__init__(self, parent, soya.Model.get("caterpillar_head"))
 		self.speed                  = soya.Vector(self, 0.0, 0.0, 0.0)
 		self.rotation_y_speed = 0.0
+		
+		# VERY IMPORTANT!
+		#
+		# The TravelingCamera use raypicking for determining through what the camera can go or not.
+		# We thus have to DISABLE raypicking on the caterpillar itself!
+		# This can be done by setting the caterpillar's solid attribute to 0.
+		
 		self.solid = 0
 		
 	def begin_round(self):
-		soya.Volume.begin_round(self)
+		soya.Body.begin_round(self)
 		
 		for event in soya.process_event():
 			if event[0] == soya.sdlconst.KEYDOWN:
@@ -57,8 +62,8 @@ class CaterpillarHead(soya.Volume):
 				elif event[1] == soya.sdlconst.K_DOWN:   self.speed.z =  0.1
 				elif event[1] == soya.sdlconst.K_LEFT:   self.rotation_y_speed =  10.0
 				elif event[1] == soya.sdlconst.K_RIGHT:  self.rotation_y_speed = -10.0
-				elif event[1] == soya.sdlconst.K_q:      soya.IDLER.stop()
-				elif event[1] == soya.sdlconst.K_ESCAPE: soya.IDLER.stop()
+				elif event[1] == soya.sdlconst.K_q:      soya.MAIN_LOOP.stop()
+				elif event[1] == soya.sdlconst.K_ESCAPE: soya.MAIN_LOOP.stop()
 			
 			if event[0] == soya.sdlconst.KEYUP:
 				if   event[1] == soya.sdlconst.K_UP:     self.speed.z = 0.0
@@ -69,25 +74,30 @@ class CaterpillarHead(soya.Volume):
 		self.rotate_y(self.rotation_y_speed)
 		
 	def advance_time(self, proportion):
-		soya.Volume.advance_time(self, proportion)
+		soya.Body.advance_time(self, proportion)
 		self.add_mul_vector(proportion, self.speed)
 
 
-class CaterpillarPiece(soya.Volume):
+class CaterpillarPiece(soya.Body):
 	def __init__(self, parent, previous):
-		soya.Volume.__init__(self, parent, soya.Shape.get("caterpillar"))
+		soya.Body.__init__(self, parent, soya.Model.get("caterpillar"))
 		self.previous = previous
 		self.speed = soya.Vector(self, 0.0, 0.0, -0.2)
+		
+		# VERY IMPORTANT!
+		#
+		# See above.
+		
 		self.solid = 0
 		
 	def begin_round(self):
-		soya.Volume.begin_round(self)
+		soya.Body.begin_round(self)
 		self.look_at(self.previous)
 		if self.distance_to(self.previous) < 1.5: self.speed.z =  0.0
 		else:                                     self.speed.z = -0.2
 		
 	def advance_time(self, proportion):
-		soya.Volume.advance_time(self, proportion)
+		soya.Body.advance_time(self, proportion)
 		self.add_mul_vector(proportion, self.speed)
 		
 
@@ -109,12 +119,7 @@ light.set_xyz(2.0, 5.0, 0.0)
 camera = soya.TravelingCamera(scene)
 
 traveling = soya.ThirdPersonTraveling(caterpillar_head)
-#traveling = soya.ThirdPersonTraveling(soya.Point(caterpillar_head, 0.0, 1.0, 0.0))
 traveling.distance = 15.0
-#traveling.smooth_move     = 1
-traveling.smooth_rotation = 0
-#traveling.direction = soya.Vector(camera, 0.0, 1.0, 2.0)
-#traveling.incline_as = None
 
 camera.add_traveling(traveling)
 camera.speed = 0.3
@@ -122,4 +127,4 @@ camera.set_xyz(0.0, 15.0, 15.0)
 camera.look_at(caterpillar_head)
 soya.set_root_widget(camera)
 
-soya.Idler(scene).idle()
+soya.MainLoop(scene).main_loop()
